@@ -31,20 +31,30 @@
 
 from __future__ import annotations
 
-from typing import List, Tuple, Union
+import logging as lggg
+from typing import Any, Callable, List, Tuple, Union
 
-from matplotlib.gridspec import GridSpec as grid_spec_t
-from matplotlib.pyplot import Axes as backend_frame_2d_t
-from matplotlib.pyplot import Figure as backend_figure_t
-from matplotlib.pyplot import figure as NewBackendFigure
+import matplotlib as mlpl  # noqa
+import matplotlib.pyplot as pypl  # noqa
+from matplotlib.artist import Artist as backend_plot_t  # noqa
+from matplotlib.collections import Collection as collection_t  # noqa
+from matplotlib.gridspec import GridSpec as grid_spec_t  # noqa
+from matplotlib.markers import MarkerStyle as marker_style_t  # noqa
+from matplotlib.pyplot import Axes as backend_frame_2d_t  # noqa
+from matplotlib.pyplot import Figure as backend_figure_t  # noqa
+from matplotlib.pyplot import figure as NewBackendFigure  # noqa
 from mpl_toolkits.mplot3d import Axes3D as backend_frame_3d_t
 
-from babelplot.backend.base import backend_plot_h
-from babelplot.backend.plot import plot_e, TranslatedArguments, UNAVAILABLE
-from babelplot.base.frame import frame_t as base_frame_t
-from babelplot.base.frame import dim_e
-from babelplot.base.figure import figure_t as base_figure_t
-from babelplot.base.plot import plot_t as base_plot_t
+from babelplot.backend.specification.plot import (
+    TranslatedArguments,
+    UNAVAILABLE_for_this_DIM,
+    plot_e,
+)
+from babelplot.type.base import backend_element_h
+from babelplot.type.dimension import dim_e
+from babelplot.type.figure import figure_t as base_figure_t
+from babelplot.type.frame import frame_t as base_frame_t
+from babelplot.type.plot import plot_t as base_plot_t
 
 
 NAME = "Matplotlib"
@@ -53,6 +63,11 @@ NAME = "Matplotlib"
 backend_frame_h = Union[backend_frame_2d_t, backend_frame_3d_t]
 
 
+lggg.basicConfig(
+    format="%(levelname)s[%(module)s.%(funcName)s()@%(lineno)d] %(message)s"
+)
+
+
 def _NewFrame(
     figure: backend_figure_t,
     _: int,
@@ -79,11 +94,11 @@ def _NewFrame(
 
 def _NewPlot(
     frame: frame_t,
-    type_: Union[str, plot_e, type(backend_plot_h)],
+    type_: Union[str, plot_e, Callable],
     *args,
     title: str = None,  # If _, then it is swallowed by kwargs!
     **kwargs,
-) -> backend_plot_h:
+) -> tuple[Any, Callable]:
     """"""
     if isinstance(type_, str):
         if plot_e.IsValid(type_):
@@ -105,7 +120,43 @@ def _NewPlot(
     args, kwargs = TranslatedArguments(
         plot_function, args, kwargs, PARAMETERS_TRANSLATIONS
     )
-    output = plot_function(frame.backend_frame, *args, **kwargs)
+    output = plot_function(frame.backend, *args, **kwargs)
+
+    return output, plot_function
+
+
+def _DefaultProperties(type_: Callable, /) -> dict[str, Any]:
+    """"""
+    name = type_.__name__
+    properties = mlpl.rcParams.find_all(f"^{name}\\.")
+
+    return {_key.replace(f"{name}.", ""): _vle for _key, _vle in properties.items()}
+
+
+def _SetProperty(element: backend_element_h, name: str, value: Any, /) -> None:
+    """"""
+    if name == "marker":
+        new_marker = marker_style_t(value)
+        element.set_paths((new_marker.get_path(),))
+    else:
+        property_ = {name: value}
+        try:
+            pypl.setp(element, **property_)
+        except AttributeError:
+            lggg.warning(
+                f'Property "{name}": Invalid property for element of type "{type(element).__name__}"'
+            )
+
+
+def _Property(element: backend_element_h, name: str, /) -> Any:
+    """"""
+    try:
+        output = pypl.getp(element, property=name)
+    except AttributeError:
+        output = None
+        lggg.warning(
+            f'Property "{name}": Invalid property for element of type "{type(element).__name__}"'
+        )
 
     return output
 
@@ -131,7 +182,7 @@ def _ShowPreparation(
             rights[col] - lefts[col],
             tops[row] - bottoms[row],
         )
-        frame.backend_frame.set_position((left, bottom, width, height))
+        frame.backend.set_position((left, bottom, width, height))
 
 
 def _Show(
@@ -146,10 +197,28 @@ def _Show(
     event_manager.start_event_loop()
 
 
-plot_t: base_plot_t = type("plot_t", (base_plot_t,), {})
-frame_t: base_frame_t = type(
-    "frame_t", (base_frame_t,), {"plot_class": plot_t, "NewBackendPlot": _NewPlot}
+# noinspection PyTypeChecker
+plot_t: base_plot_t = type(
+    "plot_t",
+    (base_plot_t,),
+    {
+        "BackendDefaultProperties": staticmethod(_DefaultProperties),
+        "BackendSetProperty": staticmethod(_SetProperty),
+        "BackendProperty": staticmethod(_Property),
+    },
 )
+# noinspection PyTypeChecker
+frame_t: base_frame_t = type(
+    "frame_t",
+    (base_frame_t,),
+    {
+        "plot_class": plot_t,
+        "NewBackendPlot": _NewPlot,
+        "BackendSetProperty": staticmethod(_SetProperty),
+        "BackendProperty": staticmethod(_Property),
+    },
+)
+# noinspection PyTypeChecker
 figure_t: base_figure_t = type(
     "figure_t",
     (base_figure_t,),
@@ -159,60 +228,51 @@ figure_t: base_figure_t = type(
         "NewBackendFrame": staticmethod(_NewFrame),
         "BackendShowPreparation": staticmethod(_ShowPreparation),
         "BackendShow": staticmethod(_Show),
+        "BackendSetProperty": staticmethod(_SetProperty),
+        "BackendProperty": staticmethod(_Property),
     },
 )
 
 
-# TODO: change pos_arg_t,... with number of pos args, or tuple of pos arg names, for doc.
-#     Or even remove all the parameter definition, which is never used, right?
-#     Or simply describe the accepted positional arguments (order and meaning), the keywords ones being defined in
-#     the backend documentation (except for their corresponding babelplot translations).
-
-
 PLOTS = {
     plot_e.SCATTER: (
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
         backend_frame_2d_t.scatter,
         backend_frame_3d_t.scatter,
     ),
     plot_e.SURFACE: (
-        UNAVAILABLE,
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
+        UNAVAILABLE_for_this_DIM,
         backend_frame_3d_t.plot_surface,
     ),
     plot_e.LEVELSET: (
-        UNAVAILABLE,
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
+        UNAVAILABLE_for_this_DIM,
         backend_frame_3d_t.contour,
     ),
     plot_e.PIE: (
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
         backend_frame_2d_t.pie,
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
     ),
     plot_e.BARH: (
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
         backend_frame_2d_t.barh,
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
     ),
     plot_e.BARV: (
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
         backend_frame_2d_t.bar,
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
     ),
     plot_e.BAR3: (
-        UNAVAILABLE,
-        UNAVAILABLE,
+        UNAVAILABLE_for_this_DIM,
+        UNAVAILABLE_for_this_DIM,
         backend_frame_2d_t.hist2d,
     ),
 }
 
 
-# TODO: allow several translations: str->str (valid for all plots), (plot_e, Callable, int), and (plot_e, Callable, str)
-#     Then look for key in complex to simple order (tuples, then str). Also allow conversion from keyword here to
-#     positional in backend.
-
-
 PARAMETERS_TRANSLATIONS = {
     "color": "c",
     "color_edge": "edgecolors",
