@@ -33,17 +33,17 @@ from __future__ import annotations
 
 from typing import Union
 
-import plotly.graph_objects as plly
-from plotly.basedatatypes import BasePlotlyType as backend_plot_t
-from plotly.graph_objects import Figure as backend_frame_t
-from plotly.graph_objects import Figure as backend_content_t
+import plotly.graph_objects as plly  # noqa
+from plotly.basedatatypes import BasePlotlyType as backend_plot_t  # noqa
+from plotly.graph_objects import Figure as backend_content_t  # noqa
+from plotly.graph_objects import Figure as backend_frame_t  # noqa
 
-from babelplot.backend.plot import plot_e  # , TranslatedArguments
-from babelplot.backend.html import Show as BackendShow
-from babelplot.base.frame import frame_t as base_frame_t
-from babelplot.base.frame import dim_e
-from babelplot.base.figure import figure_t as base_figure_t
-from babelplot.base.plot import plot_t as base_plot_t
+from babelplot.backend.brick.html import Show as BackendShow
+from babelplot.backend.specification.plot import plot_e  # , TranslatedArguments
+from babelplot.type.dimension import dim_e
+from babelplot.type.figure import figure_t as base_figure_t
+from babelplot.type.frame import frame_t as base_frame_t
+from babelplot.type.plot import plot_t as base_plot_t
 
 
 NAME = "Plotly"
@@ -79,7 +79,7 @@ def _NewPlot(
     *args,
     title: str = None,  # If _, then it is swallowed by kwargs!
     **kwargs,
-) -> backend_plot_t:
+) -> tuple[backend_plot_t, type(backend_plot_t)]:
     """"""
     if isinstance(type_, str):
         if plot_e.IsValid(type_):
@@ -93,9 +93,9 @@ def _NewPlot(
 
     # args, kwargs = TranslatedArguments(args, kwargs, PARAMETERS_TRANSLATIONS)
     output = type_(*args, **kwargs)
-    frame.backend_frame.add_trace(output)
+    frame.backend.add_trace(output)
 
-    return output
+    return output, type_
 
 
 def _HTMLofContent(_, content: backend_content_t, *__, **___) -> str:
@@ -103,10 +103,13 @@ def _HTMLofContent(_, content: backend_content_t, *__, **___) -> str:
     return content.to_html(include_plotlyjs="cdn")  # True=>blank figure
 
 
+# noinspection PyTypeChecker
 plot_t: base_plot_t = type("plot_t", (base_plot_t,), {})
+# noinspection PyTypeChecker
 frame_t: base_frame_t = type(
     "frame_t", (base_frame_t,), {"plot_class": plot_t, "NewBackendPlot": _NewPlot}
 )
+# noinspection PyTypeChecker
 figure_t: base_figure_t = type(
     "figure_t",
     (base_figure_t,),
@@ -114,7 +117,7 @@ figure_t: base_figure_t = type(
         "frame_class": frame_t,
         "NewBackendFrame": staticmethod(_NewFrame),
         "BackendShow": staticmethod(BackendShow),
-        "_HTMLofContent": staticmethod(_HTMLofContent),
+        "HTMLofContent": staticmethod(_HTMLofContent),
     },
 )
 
